"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RulesNoOpDisplayer = exports.RuleTableDisplayer = exports.RuleDetailDisplayer = void 0;
const code_analyzer_core_1 = require("@salesforce/code-analyzer-core");
const StylingUtil_1 = require("../utils/StylingUtil");
const messages_1 = require("../messages");
class AbstractRuleDisplayer {
    display;
    constructor(display) {
        this.display = display;
    }
    view(rules) {
        this.displayLineSeparator();
        if (rules.length > 0) {
            this._view(rules);
            this.displayLineSeparator();
        }
    }
    displayLineSeparator() {
        this.display.displayLog("");
    }
}
class RuleDetailDisplayer extends AbstractRuleDisplayer {
    _view(rules) {
        const styledRules = [];
        for (let i = 0; i < rules.length; i++) {
            const rule = rules[i];
            const header = (0, messages_1.getMessage)(messages_1.BundleName.RuleViewer, 'summary.detail.header', [i + 1, rule.getName()]);
            const severity = rule.getSeverityLevel();
            const body = {
                severity: `${severity.valueOf()} (${code_analyzer_core_1.SeverityLevel[severity]})`,
                engine: rule.getEngineName(),
            };
            const keys = ['severity', 'engine'];
            if (rule.getTags().length > 0) {
                body['tags'] = rule.getTags().join(', ');
                keys.push('tags');
            }
            if (rule.getResourceUrls().length == 1) {
                body['resource'] = rule.getResourceUrls()[0];
                keys.push('resource');
            }
            else if (rule.getResourceUrls().length > 1) {
                body['resources'] = rule.getResourceUrls();
                keys.push('resources');
            }
            if (rule.getDescription().length > 0) {
                body['description'] = rule.getDescription();
                keys.push('description');
            }
            styledRules.push((0, StylingUtil_1.toStyledHeaderAndBody)(header, body, keys));
        }
        this.display.displayLog(styledRules.join('\n\n'));
    }
}
exports.RuleDetailDisplayer = RuleDetailDisplayer;
const TABLE_COLUMNS = {
    num: {
        header: (0, messages_1.getMessage)(messages_1.BundleName.RuleViewer, 'summary.table.num-column')
    },
    name: {
        header: (0, messages_1.getMessage)(messages_1.BundleName.RuleViewer, 'summary.table.name-column')
    },
    engine: {
        header: (0, messages_1.getMessage)(messages_1.BundleName.RuleViewer, 'summary.table.engine-column')
    },
    severity: {
        header: (0, messages_1.getMessage)(messages_1.BundleName.RuleViewer, 'summary.table.severity-column')
    },
    tag: {
        header: (0, messages_1.getMessage)(messages_1.BundleName.RuleViewer, 'summary.table.tag-column')
    }
};
class RuleTableDisplayer extends AbstractRuleDisplayer {
    _view(rules) {
        const ruleJsons = rules.map((rule, idx) => {
            const severity = rule.getSeverityLevel();
            return {
                num: idx + 1,
                name: rule.getName(),
                engine: rule.getEngineName(),
                severity: `${severity.valueOf()} (${code_analyzer_core_1.SeverityLevel[severity]})`,
                tag: rule.getTags().join(', ')
            };
        });
        this.display.displayTable(ruleJsons, TABLE_COLUMNS);
    }
}
exports.RuleTableDisplayer = RuleTableDisplayer;
class RulesNoOpDisplayer {
    view(_rules) {
        return;
    }
}
exports.RulesNoOpDisplayer = RulesNoOpDisplayer;
//# sourceMappingURL=RuleViewer.js.map